#!/bin/sh

# NAME:
#	rtept.sh - extract waypoints from GPX file
#
# SYNOPSIS:
#	rtept.sh -i "input" -w "waypoints" -e "ext"
#
# DESCRIPTION:
#	For each 'rtept' in "$input" save it in "$waypoints$name$ext"
#
#	This makes it easy to compose new routes from a library of
#	waypoints.
#
# SEE ALSO:
#	GPX.py(1)
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#

# RCSid:
#	$Id: rtept.sh,v 1.3 2021/08/28 20:08:09 sjg Exp $
#
#	@(#) Copyright (c) 2021 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

error() {
    echo "$ERROR: $@" >&2
    exit 1
}

opt_e=.rtept
opt_str='e:i:w:'
. setopts.sh

test -s ${opt_i:-/dev/null} || error "must specify '-i input-file'"

case "$opt_w" in
*/) mkdir -p $opt_w;;
*/*-) mkdir -p ${opt_w%/*};;
esac

egrep -n '</*(rte|name)' $opt_i | tr ':<>' '   ' |
while read n tag rest
do
    : n=$n tag=$tag rest=$rest
    case "$tag" in
    rte*) ltag=$tag start=$n;;
    name) name=`echo $rest | sed 's, */name,,;s,[ -],_,g'`
        case "$name" in
	0*) name=${rte_name}-$name;;
	esac
        eval ${ltag}_name=$name
        ;;
    /rtept) sed -n "$start,${n}p" $opt_i > $opt_w$name$opt_e;;
    esac
done

        
